@@ -97,7 +97,7 @@ class Kitchen(arcade.Window):
         self.GAME_PAUSE = False
         self.frame_count = 0
         self.frames = 10
-        self.end_text = '厨房炸了'
+        self.end_text = '扫除失败'
         self.end_color = arcade.color.RED
         self.end_size = 48
         self.score = 0
